@@ -681,7 +681,7 @@ g_utf8_strchug (char *string)
 {
 	char     *scan;
 	gunichar  c;
-                                                                                
+
 	g_return_val_if_fail (string != NULL, NULL);
 	
 	scan = string;
@@ -725,7 +725,7 @@ g_utf8_strchomp (char *string)
 }
 
 
-#define g_utf8_strstrip( string )    g_utf8_strchomp (g_utf8_strchug (string))
+#define g_utf8_strstrip(string)    g_utf8_strchomp (g_utf8_strchug (string))
 
 
 char **
@@ -940,20 +940,20 @@ get_last_field (const char *line,
 
 
 char *
-get_temp_work_dir_name ()
+get_temp_work_dir_name (void)
 {
 	char       *result = NULL;
 	static int  count = 0;
 	int         try = 0;
 
 	do {
+		g_free (result);
 		result = g_strdup_printf ("%s%s.%d.%d",
 					  g_get_tmp_dir (),
 					  "/file-roller",
 					  getpid (),
 					  count++);
-	} while (g_file_test (result, G_FILE_TEST_EXISTS)
-		 && (try++ < MAX_TRIES));
+	} while (path_is_file (result) && (try++ < MAX_TRIES));
 
 	return result;
 }
