@@ -28,6 +28,7 @@
 #include <glade/glade.h>
 #include "file-utils.h"
 #include "fr-process.h"
+#include "fr-stock.h"
 #include "gconf-utils.h"
 #include "window.h"
 #include "typedefs.h"
@@ -115,11 +116,9 @@ int main (int argc, char **argv)
                 g_error ("Cannot initialize the Virtual File System.");
 
 	glade_gnome_init ();
-
+	fr_stock_init ();
 	init_session (argv);
-
 	initialize_data ();
-
 	prepare_app (pctx);
 	poptFreeContext (pctx);
 
@@ -138,7 +137,7 @@ initialize_data ()
 {
 	char *icon_path = PIXMAPSDIR "/file-roller.png";
 
-	if (! g_file_test (icon_path, G_FILE_TEST_EXISTS))
+	if (! path_is_file (icon_path))
                 g_warning ("Could not find %s", icon_path);
 	else
 		gnome_window_icon_set_default_from_file (icon_path);
