@@ -31,7 +31,6 @@
 #include "dlg-extract.h"
 #include "dlg-open-with.h"
 #include "dlg-password.h"
-#include "dlg-preferences.h"
 #include "dlg-prop.h"
 #include "menu-callbacks.h"
 
@@ -45,17 +44,14 @@ enum {
 	FILE_MENU_SEP1,
 	FILE_MENU_SAVE_AS_ARCHIVE,
 	FILE_MENU_SEP2,
-	FILE_MENU_OPEN,
-	FILE_MENU_VIEW,
-	FILE_MENU_SEP3,
 	FILE_MENU_RANAME_ARCHIVE,
 	FILE_MENU_COPY_ARCHIVE,
 	FILE_MENU_MOVE_ARCHIVE,
 	FILE_MENU_DELETE_ARCHIVE,
 	FILE_MENU_TEST,
-	FILE_MENU_SEP4,
+	FILE_MENU_SEP3,
 	FILE_MENU_ARCHIVE_PROP,
-	FILE_MENU_SEP5,
+	FILE_MENU_SEP4,
 	FILE_MENU_CLOSE_ARCHIVE,
 	FILE_MENU_EXIT,
 	FILE_MENU_LENGTH
@@ -80,20 +76,6 @@ GnomeUIInfo file_menu[] = {
 
 	GNOMEUIINFO_SEPARATOR,
 
-	{ GNOME_APP_UI_ITEM, 
-	  N_("Open Fi_les..."), N_("Open selected files with an application"), 
-	  open_with_cb, NULL, NULL,
-	  GNOME_APP_PIXMAP_NONE, 0,
-	  0, 0, NULL },
-
-	{ GNOME_APP_UI_ITEM, 
-	  N_("_View File"), N_("View file with internal viewer"), 
-	  view_or_open_cb, NULL, NULL,
-	  GNOME_APP_PIXMAP_NONE, 0,
-	  'v', GDK_CONTROL_MASK, NULL },
-
-	GNOMEUIINFO_SEPARATOR,
-
 	{ GNOME_APP_UI_ITEM, 
 	  N_("_Rename..."), N_("Rename current archive"), 
 	  rename_archive_cb, NULL, NULL,
@@ -119,7 +101,7 @@ GnomeUIInfo file_menu[] = {
 	  0, 0, NULL },
 
 	{ GNOME_APP_UI_ITEM, 
-	  N_("_Test"), N_("Test whether the archive contains errors"),
+	  N_("_Test Integrity"), N_("Test whether the archive contains errors"),
 	  test_cb, NULL, NULL,
 	  GNOME_APP_PIXMAP_NONE, 0,
 	  0, 0, NULL },
@@ -130,7 +112,7 @@ GnomeUIInfo file_menu[] = {
 	  N_("_Properties"), N_("Show archive properties"),
 	  dlg_prop, NULL, NULL,
 	  GNOME_APP_PIXMAP_STOCK, GTK_STOCK_PROPERTIES,
-	  'i', GDK_CONTROL_MASK, NULL },
+	  0, 0, NULL },
 
 	GNOMEUIINFO_SEPARATOR,
 
@@ -143,54 +125,55 @@ GnomeUIInfo file_menu[] = {
 
 enum {
 	EDIT_MENU_ADD = 0,
-	EDIT_MENU_DELETE,
 	EDIT_MENU_EXTRACT,
-	/*EDIT_MENU_UUENCODE,*/
-	/*EDIT_MENU_COMMENT,*/
 	EDIT_MENU_SEP1,
+	EDIT_MENU_CUT,
+	EDIT_MENU_COPY,
+	EDIT_MENU_PASTE,
+	EDIT_MENU_RENAME,
+	EDIT_MENU_DELETE,
+	EDIT_MENU_SEP2,
 	EDIT_MENU_SELECT_ALL,
 	EDIT_MENU_DESELECT_ALL,
-	EDIT_MENU_SEP2,
-	EDIT_MENU_PASSWORD,
 	EDIT_MENU_SEP3,
-	EDIT_MENU_PREFERENCES,
+	EDIT_MENU_OPEN,
+	EDIT_MENU_VIEW,
+	EDIT_MENU_SEP4,
+	EDIT_MENU_PASSWORD,
+	EDIT_MENU_SEP5,
 	EDIT_MENU_LENGTH
 };
 
 GnomeUIInfo edit_menu[] = {
 	{ GNOME_APP_UI_ITEM, 
-	  N_("Add _Files..."), N_("Add files to the archive"), 
+	  N_("_Add..."), N_("Add files and folders to the archive"), 
 	  add_cb, NULL, NULL,
 	  GNOME_APP_PIXMAP_STOCK, GTK_STOCK_ADD,
-	  'z', GDK_CONTROL_MASK, NULL },
+	  0, 0, NULL },
 
 	{ GNOME_APP_UI_ITEM, 
-	  N_("_Delete Files..."), N_("Delete selected files and folders from the archive"), 
-	  dlg_delete, NULL, NULL,
-	  GNOME_APP_PIXMAP_STOCK, GTK_STOCK_REMOVE,
-	  'd', GDK_CONTROL_MASK, NULL },
-
-	{ GNOME_APP_UI_ITEM, 
-	  N_("_Extract to..."), N_("Extract files from the archive"), 
+	  N_("_Extract..."), N_("Extract files from the archive"), 
 	  dlg_extract, NULL, NULL,
 	  GNOME_APP_PIXMAP_NONE, 0,
-	  'x', GDK_CONTROL_MASK, NULL },
-
-	/* FIXME
-	{ GNOME_APP_UI_ITEM, 
-	  N_("_UUencode..."), " ",
-	  NULL, NULL, NULL,
-	  GNOME_APP_PIXMAP_NONE, 0,
 	  0, 0, NULL },
-	*/
 
-	/* FIXME
+	GNOMEUIINFO_SEPARATOR,
+
+	GNOMEUIINFO_MENU_CUT_ITEM (cut_cb, NULL),
+	GNOMEUIINFO_MENU_COPY_ITEM (copy_cb, NULL),
+	GNOMEUIINFO_MENU_PASTE_ITEM (paste_cb, NULL),
+
 	{ GNOME_APP_UI_ITEM, 
-	  N_("C_omment..."), " ",
-	  NULL, NULL, NULL,
+	  N_("_Rename..."), N_("Rename selection"), 
+	  rename_cb, NULL, NULL,
 	  GNOME_APP_PIXMAP_NONE, 0,
+	  GDK_F2, 0, NULL },
+
+	{ GNOME_APP_UI_ITEM, 
+	  N_("_Delete..."), N_("Delete selection from the archive"), 
+	  dlg_delete, NULL, NULL,
+	  GNOME_APP_PIXMAP_STOCK, GTK_STOCK_REMOVE,
 	  0, 0, NULL },
-	*/
 
 	GNOMEUIINFO_SEPARATOR,
 
@@ -204,7 +187,21 @@ GnomeUIInfo edit_menu[] = {
 	  N_("Dese_lect All"), N_("Deselect all files"), 
 	  deselect_all_cb, NULL, NULL,
 	  GNOME_APP_PIXMAP_NONE, 0,
-	  'a', GDK_SHIFT_MASK | GDK_CONTROL_MASK, NULL },
+	  0, 0, NULL },
+
+	GNOMEUIINFO_SEPARATOR,
+
+	{ GNOME_APP_UI_ITEM, 
+	  N_("Open Fi_les..."), N_("Open selected files with an application"), 
+	  open_with_cb, NULL, NULL,
+	  GNOME_APP_PIXMAP_NONE, 0,
+	  0, 0, NULL },
+
+	{ GNOME_APP_UI_ITEM, 
+	  N_("_View File"), N_("View file with internal viewer"), 
+	  view_or_open_cb, NULL, NULL,
+	  GNOME_APP_PIXMAP_NONE, 0,
+	  0, 0, NULL },
 
 	GNOMEUIINFO_SEPARATOR,
 
@@ -214,14 +211,6 @@ GnomeUIInfo edit_menu[] = {
 	  GNOME_APP_PIXMAP_NONE, 0,
 	  0, 0, NULL },
 
-	GNOMEUIINFO_SEPARATOR,
-
-	{ GNOME_APP_UI_ITEM, 
-	  N_("_Preferences"), N_("Edit File Roller preferences"), 
-	  dlg_preferences, NULL, NULL,
-	  GNOME_APP_PIXMAP_STOCK, GTK_STOCK_PREFERENCES, 
-	  'p', GDK_CONTROL_MASK, NULL },
-
 	GNOMEUIINFO_END
 };
 
@@ -316,8 +305,7 @@ enum {
 	VIEW_MENU_SEP4,
 	VIEW_MENU_SORT_LIST,
 	VIEW_MENU_SEP5,
-	VIEW_MENU_LAST_OUTPUT,
-	VIEW_MENU_NEW_WINDOW
+	VIEW_MENU_LAST_OUTPUT
 };
 
 GnomeUIInfo view_menu[] = {
@@ -363,12 +351,6 @@ GnomeUIInfo view_menu[] = {
 	  GNOME_APP_PIXMAP_NONE, 0,
 	  0, 0, NULL },
 
-	{ GNOME_APP_UI_ITEM, 
-	  N_("New _Window"), N_("Open a new window"), 
-	  new_window_cb, NULL, NULL,
-	  GNOME_APP_PIXMAP_NONE, 0,
-	  0, 0, NULL },
-
 	GNOMEUIINFO_END
 };
 
@@ -407,26 +389,39 @@ GnomeUIInfo main_menu[] = {
 /* popup menus. */
 
 enum {
-	FILE_POPUP_MENU_OPEN,
+	FILE_POPUP_MENU_OPEN = 0,
+	FILE_POPUP_MENU_OPEN_WITH = 0,
 	FILE_POPUP_MENU_VIEW,
 	FILE_POPUP_MENU_SEP1,
 	FILE_POPUP_MENU_ADD,
-	FILE_POPUP_MENU_DELETE,
 	FILE_POPUP_MENU_EXTRACT,
 	FILE_POPUP_MENU_SEP2,
-	FILE_POPUP_MENU_SELECT_ALL
+	FILE_POPUP_MENU_CUT,
+	FILE_POPUP_MENU_COPY,
+	FILE_POPUP_MENU_PASTE,
+	FILE_POPUP_MENU_RENAME,
+	FILE_POPUP_MENU_DELETE,
+	FILE_POPUP_MENU_SEP3,
+	FILE_POPUP_MENU_SELECT_ALL,
+	FILE_POPUP_MENU_DESELECT_ALL
 };
 
 
 GnomeUIInfo file_popup_menu_data[] = {
 	{ GNOME_APP_UI_ITEM, 
-	  N_("Open Files..."), " ", 
+	  N_("Open"), N_("Open selected files with the standard application"),
+	  view_or_open_cb, NULL, NULL,
+	  GNOME_APP_PIXMAP_NONE, 0,
+	  0, 0, NULL },
+
+	{ GNOME_APP_UI_ITEM, 
+	  N_("Open With..."), N_("Open selected files with an application"),
 	  open_with_cb, NULL, NULL,
 	  GNOME_APP_PIXMAP_NONE, 0,
 	  0, 0, NULL },
 
 	{ GNOME_APP_UI_ITEM, 
-	  N_("View File"), N_("View file with internal viewer"), 
+	  N_("_View File"), N_("View file with internal viewer"), 
 	  view_cb, NULL, NULL,
 	  GNOME_APP_PIXMAP_NONE, 0,
 	  0, 0, NULL },
@@ -434,21 +429,33 @@ GnomeUIInfo file_popup_menu_data[] = {
 	GNOMEUIINFO_SEPARATOR,
 
 	{ GNOME_APP_UI_ITEM, 
-	  N_("Add _Files..."), N_("Add files to the archive"), 
+	  N_("_Add..."), N_("Add files and folders to the archive"), 
 	  add_cb, NULL, NULL,
 	  GNOME_APP_PIXMAP_STOCK, GTK_STOCK_ADD,
 	  0, 0, NULL },
 
 	{ GNOME_APP_UI_ITEM, 
-	  N_("_Delete Files"), N_("Delete files from the archive"), 
-	  dlg_delete, NULL, NULL,
-	  GNOME_APP_PIXMAP_STOCK, GTK_STOCK_REMOVE,
+	  N_("_Extract..."), N_("Extract files from the archive"), 
+	  dlg_extract, NULL, NULL,
+	  GNOME_APP_PIXMAP_NONE, 0,
+	  0, 0, NULL },
+
+	GNOMEUIINFO_SEPARATOR,
+
+	GNOMEUIINFO_MENU_CUT_ITEM (cut_cb, NULL),
+	GNOMEUIINFO_MENU_COPY_ITEM (copy_cb, NULL),
+	GNOMEUIINFO_MENU_PASTE_ITEM (paste_cb, NULL),
+
+	{ GNOME_APP_UI_ITEM, 
+	  N_("_Rename..."), N_("Rename selection"), 
+	  rename_cb, NULL, NULL,
+	  GNOME_APP_PIXMAP_NONE, 0,
 	  0, 0, NULL },
 
 	{ GNOME_APP_UI_ITEM, 
-	  N_("_Extract to..."), N_("Extract files from the archive"), 
-	  dlg_extract, NULL, NULL,
-	  GNOME_APP_PIXMAP_NONE, 0,
+	  N_("_Delete..."), N_("Delete selection from the archive"),
+	  dlg_delete, NULL, NULL,
+	  GNOME_APP_PIXMAP_STOCK, GTK_STOCK_REMOVE,
 	  0, 0, NULL },
 
 	GNOMEUIINFO_SEPARATOR,
